Tutorials
=========
You can find some examples on how to use martinize 2 in the martinize-examples
repository: https://github.com/marrink-lab/martinize-examples

.. Organize the tutorials in directories, so it's easier to keep their files
    together

.. toctree::
    6_adding_residues_links/index
    7_adding_modifications/index
